@@ -41,7 +41,7 @@ public class CassandraClusterConnection {
 	 * @param dropSchema set true if you want do drop the current and set up new one
 	 *  the connection to cassandra cluster
 	 */
-	protected CassandraClusterConnection(boolean dropSchema)	{
+	protected CassandraClusterConnection(boolean dropSchema) throws Exception {
 		if (hosts == null || datacenterName == null || keyspaceName == null) {
 			RunningCluster cluster = RunningCluster.getInstance(null);
 
@@ -62,7 +62,7 @@ public class CassandraClusterConnection {
 	 * @param dropSchema set true if you want to drop the current and set up new one
 	 * the connection to cassandra cluster
 	 */
-	protected CassandraClusterConnection(boolean dropSchema, String infrastructureName)	{
+	protected CassandraClusterConnection(boolean dropSchema, String infrastructureName) throws Exception {
 		if (hosts == null || datacenterName == null || keyspaceName == null) {
 			RunningCluster cluster = RunningCluster.getInstance(infrastructureName);
 			//host = cluster.getHost();
@@ -145,7 +145,7 @@ public class CassandraClusterConnection {
 		CqlSession cqlSession = configBuilder(CqlSession.builder())
 				.addContactPoints(hosts)
 				.withKeyspace(KEYSPACE_NAME)
-				.withLocalDatacenter("1")
+				.withLocalDatacenter(datacenterName)
 				.build();
 		_log.info("[OK] Connected to Keyspace {} ", KEYSPACE_NAME);
 		return cqlSession;
@@ -180,7 +180,7 @@ public class CassandraClusterConnection {
 	private static void createKeyspace(String keyspaceName, int replicationFactor) {
 		try (CqlSession cqlSession = configBuilder(CqlSession.builder())
 				.addContactPoints(hosts)
-				.withLocalDatacenter("1")
+				.withLocalDatacenter(datacenterName)
 				.build()) {
 			cqlSession.execute(SchemaBuilder.createKeyspace(keyspaceName)
 					.ifNotExists()
@@ -196,7 +196,7 @@ public class CassandraClusterConnection {
 		ResultSet toreturn;
 		try (CqlSession cqlSession = configBuilder(CqlSession.builder())
 				.addContactPoints(hosts)
-				.withLocalDatacenter("1")
+				.withLocalDatacenter(datacenterName)
 				.build()) {
 			toreturn = cqlSession.execute(SchemaBuilder.dropKeyspace(keyspaceName).ifExists().build());
 			_log.info("Keyspace {} dropped.", keyspaceName);
@@ -207,7 +207,7 @@ public class CassandraClusterConnection {
 	private void createTables(){
 		try (CqlSession cqlSession = configBuilder(CqlSession.builder())
 				.addContactPoints(hosts)
-				.withLocalDatacenter("1")
+				.withLocalDatacenter(datacenterName)
 				.withKeyspace(keyspaceName)
 				.build()) {
 
